@@ -197,16 +197,7 @@ class ContractView(BrowserView):
         """
         contract = self.current_contract(includeChangeLetters=False)
         if contract is not None:
-            start = contract.getStartdate()
-            duration = contract.getDuration()
-            if start is None or duration is None:
-                return None
-            year, month, day = start.year(), start.month(), start.day()
-            year = year + (month + duration - 1) / 12
-            month = 1 + (month + duration - 1) % 12
-            # Try not to return e.g. 31 February ...
-            first_of_month =  DateTime(year, month, 1)
-            return first_of_month + day - 1
+            return contract.expiry_date()
         return None
     
  
