@@ -287,7 +287,7 @@ class Contract(BaseContent):
         """
         base = self.base_contract()
         if base is None or base == self:
-            return '0'
+            return 0
         return base.getDaysPerWeek()
 
     def expiry_date(self):
